@@ -1,33 +1,37 @@
 package Kwiki::Notify::IRC;
-use warnings;
 use strict;
-use Kwiki::Plugin '-Base';
+use warnings;
+
+use lib 'lib';
+use Kwiki::Plugin -Base;
 use mixin 'Kwiki::Installer';
 
-our $VERSION = "0.02";
+our $VERSION = "0.04";
 
-const class_id => 'notify_irc';
+const class_id    => 'notify_irc';
 const class_title => 'Kwiki page edit notification via IRC';
 const config_file => 'notify_irc.yaml';
 
 sub register {
     my $registry = shift;
-    $registry->add(page_hook_store => 'update');
+    $registry->add( hook => 'page:store', post => 'update' );
 }
 
 sub update {
-    no warnings 'once'; # i use package variables below
+    no warnings 'once';    # i use package variables below
     require POE::Component::IKC::ClientLite;
     my $remote = POE::Component::IKC::ClientLite::create_ikc_client(
-        port => $self->config->notify_irc_daemon_port,
-        ip => $self->config->notify_irc_daemon_host,
-        name => "Kwiki$$",
+        port    => $self->hub->config->notify_irc_daemon_port,
+        ip      => $self->hub->config->notify_irc_daemon_host,
+        name    => "Kwiki$$",
         timeout => 5,
-    ) or die $POE::Component::IKC::ClientLite::error;
-    $remote->post('notify_irc/update', $self->hub->edit->pages->current->metadata);
+        )
+        or die $POE::Component::IKC::ClientLite::error;
+    my $page = $self->pages->current;
+    $page->title;
+    $remote->post( 'notify_irc/update', $page );
 }
 
-1;
 __DATA__
 
 =head1 NAME 
@@ -78,7 +82,7 @@ A comma-delimited list of channels to connect to.
 
 =head1 AUTHORS
 
-Ian Langworth <langworth.com> 
+Ian Langworth <ian@cpan.org>
 
 =head1 SEE ALSO
 
@@ -94,12 +98,12 @@ it under the same terms as Perl itself.
 =cut
 
 __config/notify_irc.yaml__
-notify_irc_daemon_host: localhost
-notify_irc_daemon_port: 17212
-notify_irc_nickname: kwiki
-notify_irc_ircname: www.kwiki.org
-notify_irc_server_host: irc.example.net
-notify_irc_server_port: 6667
+notify_irc_daemon_host:     localhost
+notify_irc_daemon_port:     17212
+notify_irc_nickname:        kwiki
+notify_irc_ircname:         www.kwiki.org
+notify_irc_server_host:     irc.example.net
+notify_irc_server_port:     6667
 notify_irc_server_channels: kwikibot, kwiki
 
 __notify-irc.pl__
@@ -109,10 +113,10 @@ use strict;
 
 use POE qw(
     Session
-    Component::IRC 
-    Component::IKC::Server 
+    Component::IRC
+    Component::IKC::Server
     Component::IKC::Specifier
-);
+    );
 
 use Term::ANSIColor qw(:constants);
 sub msg (@) { print GREEN, BOLD, " * ", RESET, "@_\n" }
@@ -121,8 +125,8 @@ sub err (@) { print RED,   BOLD, " * ", RESET, "@_\n" }
 msg 'loading configuration';
 require YAML;
 my $config = {
-    %{ YAML::LoadFile( 'config/notify_irc.yaml' ) || {} },
-    %{ YAML::LoadFile( 'config.yaml' ) || {} },
+    %{ YAML::LoadFile('config/notify_irc.yaml') || {} },
+    %{ YAML::LoadFile('config.yaml')            || {} },
 };
 
 msg 'creating daemon component';
@@ -147,7 +151,7 @@ POE::Session->create(
         irc_socketerr    => \&bot_reconnect,
         autoping         => \&bot_do_autoping,
         update           => \&update,
-        _default         => $ENV{DEBUG} ? \&bot_default : sub {},
+        _default         => $ENV{DEBUG} ? \&bot_default : sub { },
     }
 );
 
@@ -156,68 +160,79 @@ POE::Kernel->run();
 msg 'exiting';
 exit 0;
 
-sub bot_default {
-    my ($event,$args) = @_[ ARG0 .. $#_ ];
+sub bot_default
+{
+    my ( $event, $args ) = @_[ ARG0 .. $#_ ];
     err "unhandled $event";
     err "  - $_" foreach @$args;
     return 0;
-};
+}
 
-sub update {
-    my ($kernel,$heap,$meta) = @_[KERNEL,HEAP,ARG0];
+sub update
+{
+    my ( $kernel, $heap, $page ) = @_[ KERNEL, HEAP, ARG0 ];
     eval {
-        my $msg = sprintf('action update: %s by %s', 
-            $meta->{id}, $meta->{edit_by} );
-        $kernel->post(bot=>ctcp=>"#$_",$msg)
+        my $msg = sprintf( 'action update: %s by %s',
+            $page->{title}, $page->{metadata}{edit_by} );
+        $kernel->post( bot => ctcp => "#$_", $msg )
             foreach split /,\s+/, $config->{notify_irc_server_channels};
-        msg "$msg on " . localtime(time);
+        msg sprintf( "$msg on %s", scalar localtime(time) );
     };
     err "update error: $@" if $@;
 }
 
-sub bot_start {
-    my ($kernel,$heap) = @_[KERNEL,HEAP];
+sub bot_start
+{
+    my ( $kernel, $heap ) = @_[ KERNEL, HEAP ];
     msg "starting irc session";
     $kernel->alias_set('notify_irc');
     $kernel->call( IKC => publish => notify_irc => ['update'] );
     $kernel->post( bot => register => 'all' );
-    $kernel->post( bot => connect => {
-        Nick=>$config->{notify_irc_nickname},
-        Ircname=>$config->{notify_irc_ircname},
-        Username=>$ENV{USER},
-        Server=>$config->{notify_irc_server_host},
-        Port=>$config->{notify_irc_server_port},
-    });
+    $kernel->post(
+        bot => connect => {
+            Nick     => $config->{notify_irc_nickname},
+            Ircname  => $config->{notify_irc_ircname},
+            Username => $ENV{USER},
+            Server   => $config->{notify_irc_server_host},
+            Port     => $config->{notify_irc_server_port},
+        }
+    );
 }
 
-sub bot_stop {
+sub bot_stop
+{
     msg "stopping bot";
 }
 
-sub bot_connected {
-    my ($kernel,$heap) = @_[KERNEL,HEAP];
-    foreach (split /,\s+/, $config->{notify_irc_server_channels}) {
+sub bot_connected
+{
+    my ( $kernel, $heap ) = @_[ KERNEL, HEAP ];
+    foreach ( split /,\s+/, $config->{notify_irc_server_channels} )
+    {
         msg "joining channel #$_";
-        $kernel->post(bot=>join=>"#$_")
+        $kernel->post( bot => join => "#$_" );
     }
 }
 
-sub bot_motd {
+sub bot_motd
+{
     msg '[motd] ' . $_[ARG1];
 }
 
-sub bot_do_autoping {
-    my ($kernel,$heap) = @_[KERNEL,HEAP];
-    $kernel->post(bot=>userhost=>$config->{notify_irc_nickname})
-      unless $heap->{seen_traffic};
+sub bot_do_autoping
+{
+    my ( $kernel, $heap ) = @_[ KERNEL, HEAP ];
+    $kernel->post( bot => userhost => $config->{notify_irc_nickname} )
+        unless $heap->{seen_traffic};
     $heap->{seen_traffic} = 0;
-    $kernel->delay(autoping=>300);
+    $kernel->delay( autoping => 300 );
 }
 
-sub bot_reconnect {
-    my ($kernel,$heap) = @_[KERNEL,HEAP];
-    err "reconnect: ".$_[ARG0];
-    $kernel->delay(autoping=>undef);
-    $kernel->delay(connect=>60);
+sub bot_reconnect
+{
+    my ( $kernel, $heap ) = @_[ KERNEL, HEAP ];
+    err "reconnect: " . $_[ARG0];
+    $kernel->delay( autoping => undef );
+    $kernel->delay( connect  => 60 );
 }
 
